Interdiff:

diff --git a/lib/cmdlib/instance_operation.py
b/lib/cmdlib/instance_operation.py
index a3135cf..4129bb0 100644
--- a/lib/cmdlib/instance_operation.py
+++ b/lib/cmdlib/instance_operation.py
@@ -19,7 +19,12 @@
 # 02110-1301, USA.


-"""Logical units dealing with operation of instance (start/stop/...)."""
+"""Logical units dealing with instance operations (start/stop/...).
+
+Those operations have in common that they affect the operating system in a
+running instance directly.
+
+"""

 import logging


Reworded commit message to:

    cmdlib: Extract operations related functionality

    Split instance.py further by extracting instance operations
    (start/stop/reboot/etc.) related logical units and functions to
    instance_operation.py.

    The extracted operations have in common that they affect the operating
    system in a running instance directly.

    Signed-off-by: Thomas Thrainer <[email protected]>



On Thu, May 16, 2013 at 8:03 PM, Bernardo Dal Seno <[email protected]>wrote:

> On 16 May 2013 19:59, Bernardo Dal Seno <[email protected]> wrote:
> > On 16 May 2013 10:23, Thomas Thrainer <[email protected]> wrote:
> >> Split instance.py further by extracting operations
> >> (start/stop/reboot/etc.) related logical units and functions to
> >> instance_operation.py.
>
> After looking at what's left, why not move also LUInstanceMove and
> LUInstanceRename here?
>

>From my point of view only those LU's actually affect the OS in an
instance, but I agree that the partition is rather arbitrary. Actually, I
tried to find a "sensible" way to extract more classes from instance.py,
because the file had initially 8000 lines... It would be great if we could
come up with a better pattern how we distribute LU classes to files, this
partitioning should rather be seen as a first step...


>
> Bernardo
>



-- 
Thomas Thrainer | Software Engineer | [email protected] |

Google Germany GmbH
Dienerstr. 12
80331 München

Registergericht und -nummer: Hamburg, HRB 86891
Sitz der Gesellschaft: Hamburg
Geschäftsführer: Graham Law, Katherine Stephens

Reply via email to